@@ -11,9 +11,10 @@
 // along with this software.
 // If not, see <https://opensource.org/licenses/MIT>.
 
+use std::borrow::Borrow;
+
 use amplify::Bipolar;
 use chacha20poly1305::aead::Error;
-use std::borrow::Borrow;
 
 use super::handshake::HandshakeError;
 use super::{chacha, hkdf};
@@ -79,8 +80,8 @@ impl NoiseEncryptor {
 impl Encrypt for NoiseEncryptor {
     fn encrypt(&mut self, buffer: impl Borrow<[u8]>) -> Vec<u8> {
         match self.encrypt_buf(buffer.borrow()) {
-            Ok(values) => return values,
-            Err(_) => return Vec::new(),
+            Ok(values) => values,
+            Err(_) => Vec::new(),
         }
     }
 }
@@ -278,12 +279,10 @@ impl NoiseTranscoder {
 
     /// Encrypt data to be sent to peer
     pub fn encrypt_buf(&mut self, buffer: &[u8]) -> Result<Vec<u8>, Error> {
-        Ok(self.encryptor.encrypt_buf(buffer)?)
+        self.encryptor.encrypt_buf(buffer)
     }
 
-    pub fn read_buf(&mut self, data: &[u8]) {
-        self.decryptor.read_buf(data)
-    }
+    pub fn read_buf(&mut self, data: &[u8]) { self.decryptor.read_buf(data) }
 
     /// Decrypt a single message. If data containing more than one message has
     /// been received, only the first message will be returned, and the rest
@@ -294,7 +293,7 @@ impl NoiseTranscoder {
         &mut self,
         new_data: Option<&[u8]>,
     ) -> Result<Option<Vec<u8>>, Error> {
-        Ok(self.decryptor.decrypt_single_message(new_data)?)
+        self.decryptor.decrypt_single_message(new_data)
     }
 
     fn increment_nonce(
@@ -319,8 +318,8 @@ impl NoiseTranscoder {
 impl Encrypt for NoiseTranscoder {
     fn encrypt(&mut self, buffer: impl Borrow<[u8]>) -> Vec<u8> {
         match self.encrypt_buf(buffer.borrow()) {
-            Ok(values) => return values,
-            Err(_) => return Vec::new(),
+            Ok(values) => values,
+            Err(_) => Vec::new(),
         }
     }
 }
@@ -362,9 +361,10 @@ impl Bipolar for NoiseTranscoder {
 
 #[cfg(test)]
 mod tests {
+    use bitcoin_hashes::hex::FromHex;
+
     use super::*;
     use crate::LNP_MSG_MAX_LEN;
-    use bitcoin_hashes::hex::FromHex;
 
     fn setup_peers() -> (NoiseTranscoder, NoiseTranscoder) {
         let chaining_key_vec = Vec::<u8>::from_hex(
